# proton-shim

**Easily run programs and scripts inside Steam game prefixes**

![pipelines](https://gitlab.com/Wisher/ProtonShim/badges/master/pipeline.svg) ![coverage](https://gitlab.com/Wisher/ProtonShim/badges/master/coverage.svg?job=test) ![release](https://gitlab.com/Wisher/ProtonShim/-/badges/release.svg)

**proton-shim** is a lightweight launcher for running Windows executables and scripts using Proton, complete with support for AppID-based compatdata, interactive or scripted mode, and advanced logging options.

## Support The Project

If you find this project useful, and would like to see more, please consider supporting me on 
[patreon](https://www.patreon.com/c/77wisher77).

Your support helps fund ongoing development, new features, other projects, and more. Every contribution is genuinely appreciated — thank you!

## Arch Linux

Proton Shim is available on the [AUR](https://aur.archlinux.org/packages/proton-shim) (Arch User Repository)!

You can install it using your favourite AUR helper:

```bash
yay -S proton-shim
```

Or manually:

```bash
git clone https://aur.archlinux.org/proton-shim.git
cd proton-shim
makepkg -sirc
```

Once installed, you can run it from anywhere using:

```bash
proton-shim [APPID]
```

## Features

- Smart executable detection (PE32, .exe, .bat, .cmd, .ps1, .msi)
- Proton version selection (prompt, or CLI)
- Proton and Game detection
- Steam AppID support for prefix isolation and compatdata
- Linux-only, designed with Steam Deck, Flatpak, and native Steam installs in mind
- Debug flags (PROTON_LOG, PROTON_DUMP_DEBUG_COMMANDS)
- Config persistence via ~/.config/ProtonShim
- Interactive prompt suppression with --no-prompt
- License viewer with --license
- Game/AppID listing with names parsed from steam files

## Usage

For the most basic usage, the following will work

```bash
./protonshim.sh [APPID]
```

For pre-selecting the executable and proton version:

```bash
./protonshim.sh --executable <PATH_TO_EXE> --proton "Proton 9.0 (Beta)" [APPID]
```

### Command-Line Options

#### Positional Argument

| Option  | Description                                                  |
| ------- | ------------------------------------------------------------ |
| `APPID` | **Required unless using** `--help`, `--license`, or `--list`.<br />Steam AppID to use for `compatdata`. You can also enter part of the game name (quoted if needed). Matching is case-insensitive and allows fuzzy matching on words (e.g. "warh dark" can match Warhammer 40,000: Darktide).<br />If the argument is numeric, it first attempts to match an installed AppID exactly. If not found, it falls back to a fuzzy name search using the provided argument. |

#### Executable Options

| Option                                            | Description                                                  |
| ------------------------------------------------- | ------------------------------------------------------------ |
| `--executable, -e <FILE>`                         | Path to the Windows file to launch. <br />If omitted, you’ll be prompted to select one from the current folder |
| `--proton, -p <VERSION>`                          | Proton version folder name (e.g. `Proton 9.0 (Beta)`) to use for execution |
| `--steam-path, -s <PATH>`                         | Override the detected Steam installation path.               |
| <code>--list, -l &lt;proton&#124;games&gt;</code> | Lists available **Proton versions** (`proton`) or detected **Steam AppIDs** with existing compatdata (`games`). Exits after displaying results. |
| `--name`                                          | Force the positional argument to be treated as a game name for lookup, even if numeric. |

#### Desktop Integration

| Option                                                | Description                                                  |
| ----------------------------------------------------- | ------------------------------------------------------------ |
| `--create-desktop <NAME>`                             | Generate a `.desktop` shortcut with the given name           |
| <code>--desktop-output &lt;local&#124;user&gt;</code> | Choose where to place the .desktop file, defaults to user if not specified:<br />- 'local' = current directory<br />- 'user'  = `~/.local/share/applications` (visible in your start menu) |
| `--icon <PATH>`                                       | Icon to use in the `.desktop` file (e.g. `PNG` or `.svg` path, or just 'steam')<br />Defaults to steam if not specified |

#### Wrapper Generation

| Option                                                  | Description                                                  |
| ------------------------------------------------------- | ------------------------------------------------------------ |
| `--create-wrapper <NAME>`                               | Generate a standalone wrapper script with the given name (will relaunch the same executable with the same Proton and AppID) |
| <code>--wrapper-output &lt;local&#124;global&gt;</code> | Choose wrapper output location:<br />- `local`: current working directory (default)<br />- `global`: `/usr/local/bin` (uses `sudo` automtatically, executable globally) |

#### Behaviour Flags

| Option           | Description                                                  |
| ---------------- | ------------------------------------------------------------ |
| `--debug, -d`    | Enables `PROTON_LOG` and `PROTON_DUMP_DEBUG_COMMANDS`        |
| `--show-command` | Prints the final Proton command                              |
| `--dry-run`      | Do not run the command.<br />Desktop files are still generated if `--create-desktop` is set.<br />The final command is printed if `--show-command` is used. |
| `--yes, -y`      | Auto-confirm chmod fixes for non-executable files            |
| `--no-prompt`    | Disable all prompts. Use with `--proton` and `--executable`  |
| `--clear`        | Clears cached persistent config files and exits.             |

#### General

| Option          | Description                        |
| --------------- | ---------------------------------- |
| `--help, -h`    | Show usage info and exit           |
| `--version, -v` | Print proton-shim version and exit |
| `--license`     | Print MIT License and exit         |

### Additional Arguments

| Option | Description                                                  |
| ------ | ------------------------------------------------------------ |
| `--`   | Everything after `--` is passed directly as additional arguments to the launched executable under Proton |

## Example

```bash
./proton-shim.sh --executable TLDWorkshop.exe --proton "Proton 9.0 (Beta)" 1017180
```

## Compatability

Should work with:

- Native or Flatpack Steam installs
- Steam Deck
- Proton GE installations

## Persistent Config

Steam installation path is cached & stored in:

> `~/.config/proton-shim/config_steam`

You can override it at any time with --steam-path.

## Troubleshooting

If your executable fails to launch:

- Ensure you have selected the correct Proton version with `--proton` or during interactive selection.
- Verify the Steam AppID or game name is correct.
- Launch the game once in Steam to initialize its prefix if you have not done so since installation or updates.
- Use `--debug` to enable Proton debug logging for deeper inspection.
- Use `--show-command` to preview the generated Proton command for manual testing.
- If your wrapper script fails to launch, ensure it has execute permissions (`chmod +x wrappername`) and that Proton and Steam are properly installed.

## License

Licensed under the MIT License. Run with --license for full terms

## Author

Phillip MacNaughton ("Wisher")